==> moodle-1.5-mysql.tgz: moodle/lang/tl/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5 ALPHA (2005051500)


$string['asset'] = 'Asset';
$string['attr_error'] = 'Masamang halaga para sa attribute na ($a->attr) sa tag na $a->tag.';
$string['autocontinue'] = 'Awto-Pagpapatuloy';
$string['badmanifest'] = 'Ilang manifest error: tingnan ang log ng mga error';
$string['browse'] = 'Silipin';
$string['browsed'] = 'Natingnan-tingnan';
$string['browsemode'] = 'Patingin-tingin na Mode';
$string['chooseapacket'] = 'Pumil o baguhin ang isang paketeng SCORM';
$string['completed'] = 'Nakumpleto';
$string['coursepacket'] = 'Pakete ng Kurso';
$string['coursestruct'] = 'Balangkas ng Kurso';
$string['datadir'] = 'Filesystem Error: Hindi malikha ang direktoryo ng datos ng kurso';
$string['details'] = 'Mga detalye ng SCO track';
$string['display'] = 'Ipakita';
$string['domxml'] = 'DOMXML external library';
$string['enablebrowse'] = 'Buhayin ang mode na pagsilip';
$string['entercourse'] = 'Ipasok ang kursong SCORM';
$string['errorlogs'] = 'Log ng mga error';
$string['exit'] = 'Lumabas sa kursong SCORM';
$string['expcoll'] = 'Palawakin/Paliitin';
$string['failed'] = 'Big';
$string['firstaccess'] = 'Unang pagpasok';
$string['found'] = 'Natagpuan ang manifest';
$string['frameheight'] = 'Itinatakda ng mas-ibig na ito ang default na taas ng frame ng SCO';
$string['framewidth'] = 'Itinatakda ng mas-ibig na ito ang default na lapad ng frame ng SCO';
$string['gradeaverage'] = 'Katamtamang marka';
$string['gradehighest'] = 'PInakamataas na marka';
$string['grademethod'] = 'Paraan ng pagmamarka';
$string['gradescoes'] = 'Sitwasyon ng mga SCO';
$string['gradesum'] = 'Kabuuang marka';
$string['guestsno'] = 'Hindi maaaring makita ng mga bisita ang mga kursong scorm';
$string['height'] = 'Taas';
$string['incomplete'] = 'Dikumpleto';
$string['lastaccess'] = 'Huling pagpasok';
$string['missing_attribute'] = 'Nawawala ang attribute na $a->attr sa tag na $a->tag';
$string['missing_tag'] = 'Nawawala ang tag na $a->tag';
$string['mode'] = 'Mode';
$string['modulename'] = 'Scorm';
$string['modulenameplural'] = 'Mga Scorm';
$string['next'] = 'Ituloy';
$string['no_attributes'] = 'Kailangang may mga attribute ang tag na $a->tag';
$string['no_children'] = 'Kailangan ay may anak ang tag na $a->tag';
$string['noactivity'] = 'Walang maiuulat';
$string['nomanifest'] = 'Hindi natagpuan ang manifest';
$string['noreports'] = 'Walang ulat na maipapakita';
$string['normal'] = 'Normal';
$string['not_corr_type'] = 'Hindi tugma ang uri para sa tag na $a->tag';
$string['notattempted'] = 'Hind kinuha';
$string['organization'] = 'Organisasyon';
$string['organizations'] = 'Mga organisasyon';
$string['packagedir'] = 'Filesystem Error: Hindi malikha ang direktoryo ng pakete';
$string['passed'] = 'Pasado';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'Buksan ang kasalukuyang SCO sa isang bagong window';
$string['position_error'] = 'Ang $a->tag na tag ay hindi maaaring maging anak ng $a->parent na tag';
$string['prev'] = 'Nakaraan';
$string['regular'] = 'Regular na Manifest';
$string['report'] = 'Ulat';
$string['review'] = 'Irebyu';
$string['scoes'] = 'Mga SCO';
$string['score'] = 'Iskor';
$string['syntax'] = 'Error sa sintaks';
$string['tag_error'] = 'Dikilalang tag ($a->tag) na may ganitong laman: $a->value';
$string['too_many_attributes'] = 'Labis ang attribute ng tag na $a->tag';
$string['too_many_children'] = 'Labis ang anak ng tag na $a->tag';
$string['totaltime'] = 'Oras';
$string['trackingloose'] = 'Babal: Mawawala ang tracking data ng paketeng SCORM na ito!';
$string['validateascorm'] = 'Suriin kung tanggap ang paketeng SCORM';
$string['validation'] = 'Resulta ng pagsusuri kung tanggap';
$string['validationtype'] = 'Ang mas-ibig na ito ay itinatakda ang DOMXML library na ginagamit sa pagtiyak kung tanggap ang SCORM Manifest. Kung hindi mo alam kung ano ito, pabayaan ang pinil na.';
$string['versionwarning'] = 'Ang bersiyon ng manifest ay mas luma sa 1.3, babala sa $a->tag na tag';
$string['viewallreports'] = 'Tingnan ang mga ulat para sa $a na pagkuha';
$string['width'] = 'Lapad';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/tl/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.6 development (2005060201)


$string['advanced'] = 'Abante';
$string['asset'] = 'Asset';
$string['attr_error'] = 'Masamang halaga para sa attribute na ($a->attr) sa tag na $a->tag.';
$string['autocontinue'] = 'Awto-Pagpapatuloy';
$string['badmanifest'] = 'Ilang manifest error: tingnan ang log ng mga error';
$string['browse'] = 'Silipin';
$string['browsed'] = 'Natingnan-tingnan';
$string['browsemode'] = 'Patingin-tingin na Mode';
$string['chooseapacket'] = 'Pumil o baguhin ang isang paketeng SCORM';
$string['completed'] = 'Nakumpleto';
$string['coursepacket'] = 'Pakete ng Kurso';
$string['coursestruct'] = 'Balangkas ng Kurso';
$string['datadir'] = 'Filesystem Error: Hindi malikha ang direktoryo ng datos ng kurso';
$string['details'] = 'Mga detalye ng SCO track';
$string['display'] = 'Ipakita';
$string['domxml'] = 'DOMXML external library';
$string['enablebrowse'] = 'Buhayin ang mode na pagsilip';
$string['entercourse'] = 'Ipasok ang kursong SCORM';
$string['errorlogs'] = 'Log ng mga error';
$string['exit'] = 'Lumabas sa kursong SCORM';
$string['expcoll'] = 'Palawakin/Paliitin';
$string['failed'] = 'Big';
$string['firstaccess'] = 'Unang pagpasok';
$string['found'] = 'Natagpuan ang manifest';
$string['frameheight'] = 'Itinatakda ng mas-ibig na ito ang default na taas ng frame ng SCO';
$string['framewidth'] = 'Itinatakda ng mas-ibig na ito ang default na lapad ng frame ng SCO';
$string['gradeaverage'] = 'Katamtamang marka';
$string['gradehighest'] = 'PInakamataas na marka';
$string['grademethod'] = 'Paraan ng pagmamarka';
$string['gradescoes'] = 'Sitwasyon ng mga SCO';
$string['gradesum'] = 'Kabuuang marka';
$string['guestsno'] = 'Hindi maaaring makita ng mga bisita ang mga kursong scorm';
$string['height'] = 'Taas';
$string['incomplete'] = 'Dikumpleto';
$string['lastaccess'] = 'Huling pagpasok';
$string['missing_attribute'] = 'Nawawala ang attribute na $a->attr sa tag na $a->tag';
$string['missing_tag'] = 'Nawawala ang tag na $a->tag';
$string['mode'] = 'Mode';
$string['modulename'] = 'Scorm';
$string['modulenameplural'] = 'Mga Scorm';
$string['next'] = 'Ituloy';
$string['no_attributes'] = 'Kailangang may mga attribute ang tag na $a->tag';
$string['no_children'] = 'Kailangan ay may anak ang tag na $a->tag';
$string['noactivity'] = 'Walang maiuulat';
$string['nomanifest'] = 'Hindi natagpuan ang manifest';
$string['noreports'] = 'Walang ulat na maipapakita';
$string['normal'] = 'Normal';
$string['not_corr_type'] = 'Hindi tugma ang uri para sa tag na $a->tag';
$string['notattempted'] = 'Hind kinuha';
$string['organization'] = 'Organisasyon';
$string['organizations'] = 'Mga organisasyon';
$string['packagedir'] = 'Filesystem Error: Hindi malikha ang direktoryo ng pakete';
$string['packagefile'] = 'Walang paketeng file na itinakda';
$string['passed'] = 'Pasado';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'Buksan ang mga Bagay na Pag-aaralan sa bagong window';
$string['position_error'] = 'Ang $a->tag na tag ay hindi maaaring maging anak ng $a->parent na tag';
$string['prev'] = 'Nakaraan';
$string['regular'] = 'Regular na Manifest';
$string['report'] = 'Ulat';
$string['review'] = 'Irebyu';
$string['scoes'] = 'Mga SCO';
$string['score'] = 'Iskor';
$string['scormcourse'] = 'Kursong SCORM';
$string['stagesize'] = 'Laki ng Frame/Windows';
$string['syntax'] = 'Error sa sintaks';
$string['tag_error'] = 'Dikilalang tag ($a->tag) na may ganitong laman: $a->value';
$string['too_many_attributes'] = 'Labis ang attribute ng tag na $a->tag';
$string['too_many_children'] = 'Labis ang anak ng tag na $a->tag';
$string['totaltime'] = 'Oras';
$string['trackingloose'] = 'Babal: Mawawala ang tracking data ng paketeng SCORM na ito!';
$string['validateascorm'] = 'Suriin kung tanggap ang paketeng SCORM';
$string['validation'] = 'Resulta ng pagsusuri kung tanggap';
$string['validationtype'] = 'Ang mas-ibig na ito ay itinatakda ang DOMXML library na ginagamit sa pagtiyak kung tanggap ang SCORM Manifest. Kung hindi mo alam kung ano ito, pabayaan ang pinil na.';
$string['versionwarning'] = 'Ang bersiyon ng manifest ay mas luma sa 1.3, babala sa $a->tag na tag';
$string['viewallreports'] = 'Tingnan ang mga ulat para sa $a na pagkuha';
$string['width'] = 'Lapad';

?>
